@@ -1,15 +1,15 @@
 from logging import getLogger
+from pkg_resources import get_distribution
 
 from django import apps
 
-from axes import get_version
 from axes.conf import settings
 
 log = getLogger(settings.AXES_LOGGER)
 
 
 class AppConfig(apps.AppConfig):
-    name = 'axes'
+    name = "axes"
     logging_initialized = False
 
     @classmethod
@@ -31,15 +31,18 @@ class AppConfig(apps.AppConfig):
             return
         cls.logging_initialized = True
 
-        log.info('AXES: BEGIN LOG')
-        log.info('AXES: Using django-axes %s', get_version())
+        log.info("AXES: BEGIN LOG")
+        log.info(
+            "AXES: Using django-axes version %s",
+            get_distribution("django-axes").version,
+        )
 
         if settings.AXES_ONLY_USER_FAILURES:
-            log.info('AXES: blocking by username only.')
+            log.info("AXES: blocking by username only.")
         elif settings.AXES_LOCK_OUT_BY_COMBINATION_USER_AND_IP:
-            log.info('AXES: blocking by combination of username and IP.')
+            log.info("AXES: blocking by combination of username and IP.")
         else:
-            log.info('AXES: blocking by IP only.')
+            log.info("AXES: blocking by IP only.")
 
     def ready(self):
         self.initialize()
