@@ -5,6 +5,9 @@ from appconf import AppConf
 
 
 class AxesAppConf(AppConf):
+    class Meta:
+        prefix = "axes"
+
     # disable plugin when set to False
     ENABLED = True
 
