@@ -1,3 +1,4 @@
+from abc import ABC, abstractmethod
 import re
 
 from django.urls import reverse
@@ -13,40 +14,57 @@ from axes.helpers import (
 )
 
 
-class AxesHandler:  # pylint: disable=unused-argument
+class AbstractAxesHandler(ABC):
+    """
+    Contract that all handlers need to follow
+    """
+
+    @abstractmethod
+    def user_login_failed(self, sender, credentials: dict, request=None, **kwargs):
+        """
+        Handles the Django ``django.contrib.auth.signals.user_login_failed`` authentication signal.
+        """
+        raise NotImplementedError("user_login_failed should be implemented")
+
+    @abstractmethod
+    def user_logged_in(self, sender, request, user, **kwargs):
+        """
+        Handles the Django ``django.contrib.auth.signals.user_logged_in`` authentication signal.
+        """
+        raise NotImplementedError("user_logged_in should be implemented")
+
+    @abstractmethod
+    def user_logged_out(self, sender, request, user, **kwargs):
+        """
+        Handles the Django ``django.contrib.auth.signals.user_logged_out`` authentication signal.
+        """
+        raise NotImplementedError("user_logged_out should be implemented")
+
+    @abstractmethod
+    def get_failures(self, request, credentials: dict = None) -> int:
+        """
+        Checks the number of failures associated to the given request and credentials.
+
+        This is a virtual method that needs an implementation in the handler subclass
+        if the ``settings.AXES_LOCK_OUT_AT_FAILURE`` flag is set to ``True``.
+        """
+        raise NotImplementedError("get_failures should be implemented")
+
+
+class AxesBaseHandler:  # pylint: disable=unused-argument
     """
     Handler API definition for implementations that are used by the ``AxesProxyHandler``.
 
     If you wish to specialize your own handler class, override the necessary methods
     and configure the class for use by setting ``settings.AXES_HANDLER = 'module.path.to.YourClass'``.
+    Make sure that new the handler is compliant with AbstractAxesHandler and make sure it extends from this mixin.
+    Refer to `AxesHandler` for an example.
 
     The default implementation that is actually used by Axes is ``axes.handlers.database.AxesDatabaseHandler``.
 
     .. note:: This is a virtual class and **can not be used without specialization**.
     """
 
-    def reset_attempts(self, *, ip_address: str = None, username: str = None) -> int:
-        """
-        Resets access attempts that match the given IP address or username.
-
-        :raises NotImplementedError: if the handler does not support resetting attempts.
-        """
-
-        raise NotImplementedError(
-            "Reset for access attempts is not supported on this backend"
-        )
-
-    def reset_logs(self, *, age_days: int = None) -> int:
-        """
-        Resets access logs that are older than given number of days.
-
-        :raises NotImplementedError: if the handler does not support resetting logs.
-        """
-
-        raise NotImplementedError(
-            "Reset for access logs is not supported on this backend"
-        )
-
     def is_allowed(self, request, credentials: dict = None) -> bool:
         """
         Checks if the user is allowed to access or use given functionality such as a login view or authentication.
@@ -76,34 +94,7 @@ class AxesHandler:  # pylint: disable=unused-argument
 
         return True
 
-    def user_login_failed(self, sender, credentials: dict, request=None, **kwargs):
-        """
-        Handles the Django ``django.contrib.auth.signals.user_login_failed`` authentication signal.
-        """
-
-    def user_logged_in(self, sender, request, user, **kwargs):
-        """
-        Handles the Django ``django.contrib.auth.signals.user_logged_in`` authentication signal.
-        """
-
-    def user_logged_out(self, sender, request, user, **kwargs):
-        """
-        Handles the Django ``django.contrib.auth.signals.user_logged_out`` authentication signal.
-        """
-
-    def post_save_access_attempt(self, instance, **kwargs):
-        """
-        Handles the ``axes.models.AccessAttempt`` object post save signal.
-        """
-
-    def post_delete_access_attempt(self, instance, **kwargs):
-        """
-        Handles the ``axes.models.AccessAttempt`` object post delete signal.
-        """
-
-    def is_blacklisted(
-        self, request, credentials: dict = None
-    ) -> bool:  # pylint: disable=unused-argument
+    def is_blacklisted(self, request, credentials: dict = None) -> bool:
         """
         Checks if the request or given credentials are blacklisted from access.
         """
@@ -113,9 +104,7 @@ class AxesHandler:  # pylint: disable=unused-argument
 
         return False
 
-    def is_whitelisted(
-        self, request, credentials: dict = None
-    ) -> bool:  # pylint: disable=unused-argument
+    def is_whitelisted(self, request, credentials: dict = None) -> bool:
         """
         Checks if the request or given credentials are whitelisted for access.
         """
@@ -137,24 +126,13 @@ class AxesHandler:  # pylint: disable=unused-argument
         """
 
         if settings.AXES_LOCK_OUT_AT_FAILURE:
-            return self.get_failures(request, credentials) >= get_failure_limit(
+            # get_failures will have to be implemented by each specialized handler
+            return self.get_failures(  # type: ignore
                 request, credentials
-            )
+            ) >= get_failure_limit(request, credentials)
 
         return False
 
-    def get_failures(self, request, credentials: dict = None) -> int:
-        """
-        Checks the number of failures associated to the given request and credentials.
-
-        This is a virtual method that needs an implementation in the handler subclass
-        if the ``settings.AXES_LOCK_OUT_AT_FAILURE`` flag is set to ``True``.
-        """
-
-        raise NotImplementedError(
-            "The Axes handler class needs a method definition for get_failures"
-        )
-
     def is_admin_site(self, request) -> bool:
         """
         Checks if the request is for admin site.
@@ -167,3 +145,43 @@ class AxesHandler:  # pylint: disable=unused-argument
             return not re.match("^%s" % admin_url, request.path)
 
         return False
+
+    def reset_attempts(self, *, ip_address: str = None, username: str = None) -> int:
+        """
+        Resets access attempts that match the given IP address or username.
+
+        This method makes more sense for the DB backend, but as it is used by the ProxyHandler
+        (via inherent), it needs to be defined here so we get compliant with all proxy methods.
+
+        Please overwrite it on each specialized handler as needed.
+        """
+        return 0
+
+    def reset_logs(self, *, age_days: int = None) -> int:
+        """
+        Resets access logs that are older than given number of days.
+
+        This method makes more sense for the DB backend, but as it is used by the ProxyHandler
+        (via inherent), it needs to be defined here so we get compliant with all proxy methods.
+
+        Please overwrite it on each specialized handler as needed.
+        """
+        return 0
+
+
+class AxesHandler(AbstractAxesHandler, AxesBaseHandler):
+    """
+    Signal bare handler implementation without any storage backend.
+    """
+
+    def user_login_failed(self, sender, credentials: dict, request=None, **kwargs):
+        pass
+
+    def user_logged_in(self, sender, request, user, **kwargs):
+        pass
+
+    def user_logged_out(self, sender, request, user, **kwargs):
+        pass
+
+    def get_failures(self, request, credentials: dict = None) -> int:
+        return 0
