@@ -10,7 +10,7 @@ from axes.attempts import (
     reset_user_attempts,
 )
 from axes.conf import settings
-from axes.handlers.base import AxesHandler
+from axes.handlers.base import AxesBaseHandler, AbstractAxesHandler
 from axes.models import AccessLog, AccessAttempt
 from axes.signals import user_locked_out
 from axes.helpers import (
@@ -25,7 +25,7 @@ from axes.helpers import (
 log = getLogger(settings.AXES_LOGGER)
 
 
-class AxesDatabaseHandler(AxesHandler):  # pylint: disable=too-many-locals
+class AxesDatabaseHandler(AbstractAxesHandler, AxesBaseHandler):
     """
     Signal handler implementation that records user login attempts to database and locks users out if necessary.
 
@@ -235,3 +235,19 @@ class AxesDatabaseHandler(AxesHandler):  # pylint: disable=too-many-locals
             AccessLog.objects.filter(
                 username=username, logout_time__isnull=True
             ).update(logout_time=request.axes_attempt_time)
+
+    def post_save_access_attempt(self, instance, **kwargs):
+        """
+        Handles the ``axes.models.AccessAttempt`` object post save signal.
+
+        When needed, all post_save actions for this backend should be located
+        here.
+        """
+
+    def post_delete_access_attempt(self, instance, **kwargs):
+        """
+        Handles the ``axes.models.AccessAttempt`` object post delete signal.
+
+        When needed, all post_delete actions for this backend should be located
+        here.
+        """
