@@ -3,19 +3,14 @@ from hashlib import md5
 from logging import getLogger
 from string import Template
 from typing import Callable, Optional, Type, Union
+from urllib.parse import urlencode
 
 from django.core.cache import caches, BaseCache
-from django.http import (
-    HttpRequest,
-    HttpResponse,
-    HttpResponseRedirect,
-    JsonResponse,
-    QueryDict,
-)
-from django.shortcuts import render
+from django.http import HttpRequest, HttpResponse, JsonResponse, QueryDict
+from django.shortcuts import render, redirect
 from django.utils.module_loading import import_string
 
-import ipware.ip2
+import ipware.ip
 
 from axes.conf import settings
 from axes.models import AccessBase
@@ -156,7 +151,7 @@ def get_client_ip_address(request) -> str:
     and parameters can be configured in the Axes package.
     """
 
-    client_ip_address, _ = ipware.ip2.get_client_ip(
+    client_ip_address, _ = ipware.ip.get_client_ip(
         request,
         proxy_order=settings.AXES_PROXY_ORDER,
         proxy_count=settings.AXES_PROXY_COUNT,
@@ -341,7 +336,10 @@ def get_lockout_response(request, credentials: dict = None) -> HttpResponse:
         return render(request, settings.AXES_LOCKOUT_TEMPLATE, context, status=status)
 
     if settings.AXES_LOCKOUT_URL:
-        return HttpResponseRedirect(settings.AXES_LOCKOUT_URL)
+        lockout_url = settings.AXES_LOCKOUT_URL
+        query_string = urlencode({"username": context["username"]})
+        url = "{}?{}".format(lockout_url, query_string)
+        return redirect(url)
 
     return HttpResponse(get_lockout_message(), status=status)
 
