@@ -12,7 +12,7 @@ from django.urls import reverse
 from django.contrib.auth import get_user_model, login, logout
 
 from axes.conf import settings
-from axes.models import AccessLog, AccessAttempt
+from axes.models import AccessAttempt
 from axes.tests.base import AxesTestCase
 
 
@@ -23,13 +23,13 @@ class DjangoLoginTestCase(TestCase):
         self.request = HttpRequest()
         self.request.session = engine.SessionStore()
 
-        self.username = 'john.doe'
-        self.password = 'hunter2'
+        self.username = "john.doe"
+        self.password = "hunter2"
 
         self.user = get_user_model().objects.create(username=self.username)
         self.user.set_password(self.password)
         self.user.save()
-        self.user.backend = 'django.contrib.auth.backends.ModelBackend'
+        self.user.backend = "django.contrib.auth.backends.ModelBackend"
 
 
 class DjangoContribAuthLoginTestCase(DjangoLoginTestCase):
@@ -62,60 +62,52 @@ class LoginTestCase(AxesTestCase):
     Always allow attempted logins for a different user from a different IP.
     """
 
-    IP_1 = '10.1.1.1'
-    IP_2 = '10.2.2.2'
-    USER_1 = 'valid-user-1'
-    USER_2 = 'valid-user-2'
-    EMAIL_1 = 'valid-email-1@example.com'
-    EMAIL_2 = 'valid-email-2@example.com'
+    IP_1 = "10.1.1.1"
+    IP_2 = "10.2.2.2"
+    USER_1 = "valid-user-1"
+    USER_2 = "valid-user-2"
+    EMAIL_1 = "valid-email-1@example.com"
+    EMAIL_2 = "valid-email-2@example.com"
 
     VALID_USERNAME = USER_1
     VALID_EMAIL = EMAIL_1
-    VALID_PASSWORD = 'valid-password'
+    VALID_PASSWORD = "valid-password"
 
     VALID_IP_ADDRESS = IP_1
 
-    WRONG_PASSWORD = 'wrong-password'
-    LOCKED_MESSAGE = 'Account locked: too many login attempts.'
+    WRONG_PASSWORD = "wrong-password"
+    LOCKED_MESSAGE = "Account locked: too many login attempts."
     LOGIN_FORM_KEY = '<input type="submit" value="Log in" />'
     ALLOWED = 302
     BLOCKED = 403
 
-    def _login(self, username, password, ip_addr='127.0.0.1', **kwargs):
+    def _login(self, username, password, ip_addr="127.0.0.1", **kwargs):
         """
         Login a user and get the response.
 
         IP address can be configured to test IP blocking functionality.
         """
 
-        post_data = {
-            'username': username,
-            'password': password,
-        }
+        post_data = {"username": username, "password": password}
 
         post_data.update(kwargs)
 
         return self.client.post(
-            reverse('admin:login'),
+            reverse("admin:login"),
             post_data,
             REMOTE_ADDR=ip_addr,
-            HTTP_USER_AGENT='test-browser'
+            HTTP_USER_AGENT="test-browser",
         )
 
     def _lockout_user_from_ip(self, username, ip_addr):
         for _ in range(settings.AXES_FAILURE_LIMIT):
             response = self._login(
-                username=username,
-                password=self.WRONG_PASSWORD,
-                ip_addr=ip_addr,
+                username=username, password=self.WRONG_PASSWORD, ip_addr=ip_addr
             )
         return response
 
     def _lockout_user1_from_ip1(self):
-        return self._lockout_user_from_ip(
-            username=self.USER_1,
-            ip_addr=self.IP_1,
-        )
+        return self._lockout_user_from_ip(username=self.USER_1, ip_addr=self.IP_1)
 
     def setUp(self):
         """
@@ -138,7 +130,9 @@ class LoginTestCase(AxesTestCase):
         """
 
         response = self._login(self.username, self.password)
-        self.assertNotContains(response, self.LOGIN_FORM_KEY, status_code=self.ALLOWED, html=True)
+        self.assertNotContains(
+            response, self.LOGIN_FORM_KEY, status_code=self.ALLOWED, html=True
+        )
 
     def test_lockout_limit_once(self):
         """
@@ -188,10 +182,7 @@ class LoginTestCase(AxesTestCase):
 
         # test until one try before the limit
         for _ in range(1, settings.AXES_FAILURE_LIMIT):
-            response = self.login(
-                is_valid_username=True,
-                is_valid_password=False,
-            )
+            response = self.login(is_valid_username=True, is_valid_password=False)
             # Check if we are in the same login page
             self.assertContains(response, self.LOGIN_FORM_KEY, html=True)
 
@@ -224,7 +215,9 @@ class LoginTestCase(AxesTestCase):
         response = self._login(self.username, self.password)
 
         # Check if we are still in the login page
-        self.assertNotContains(response, self.LOGIN_FORM_KEY, status_code=self.ALLOWED, html=True)
+        self.assertNotContains(
+            response, self.LOGIN_FORM_KEY, status_code=self.ALLOWED, html=True
+        )
 
         # now create failure_limit + 1 failed logins and then we should still
         # be able to login with valid_username
@@ -233,7 +226,9 @@ class LoginTestCase(AxesTestCase):
 
         # Check if we can still log in with valid user
         response = self._login(self.username, self.password)
-        self.assertNotContains(response, self.LOGIN_FORM_KEY, status_code=self.ALLOWED, html=True)
+        self.assertNotContains(
+            response, self.LOGIN_FORM_KEY, status_code=self.ALLOWED, html=True
+        )
 
     # Test for true and false positives when blocking by IP *OR* user (default)
     # Cache disabled. Default settings.
@@ -242,11 +237,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 1 is still blocked from IP 1.
-        response = self._login(
-            self.USER_1,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_1
-        )
+        response = self._login(self.USER_1, self.VALID_PASSWORD, ip_addr=self.IP_1)
         self.assertEqual(response.status_code, self.BLOCKED)
 
     def test_lockout_by_ip_allows_when_same_user_diff_ip_without_cache(self):
@@ -254,11 +245,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 1 can still login from IP 2.
-        response = self._login(
-            self.USER_1,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_2
-        )
+        response = self._login(self.USER_1, self.VALID_PASSWORD, ip_addr=self.IP_2)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     def test_lockout_by_ip_blocks_when_diff_user_same_ip_without_cache(self):
@@ -266,11 +253,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 2 is also locked out from IP 1.
-        response = self._login(
-            self.USER_2,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_1
-        )
+        response = self._login(self.USER_2, self.VALID_PASSWORD, ip_addr=self.IP_1)
         self.assertEqual(response.status_code, self.BLOCKED)
 
     def test_lockout_by_ip_allows_when_diff_user_diff_ip_without_cache(self):
@@ -278,11 +261,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 2 can still login from IP 2.
-        response = self._login(
-            self.USER_2,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_2
-        )
+        response = self._login(self.USER_2, self.VALID_PASSWORD, ip_addr=self.IP_2)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     # Test for true and false positives when blocking by user only.
@@ -293,11 +272,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 1 is still blocked from IP 1.
-        response = self._login(
-            self.USER_1,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_1
-        )
+        response = self._login(self.USER_1, self.VALID_PASSWORD, ip_addr=self.IP_1)
         self.assertEqual(response.status_code, self.BLOCKED)
 
     @override_settings(AXES_ONLY_USER_FAILURES=True)
@@ -306,11 +281,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 1 is also locked out from IP 2.
-        response = self._login(
-            self.USER_1,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_2
-        )
+        response = self._login(self.USER_1, self.VALID_PASSWORD, ip_addr=self.IP_2)
         self.assertEqual(response.status_code, self.BLOCKED)
 
     @override_settings(AXES_ONLY_USER_FAILURES=True)
@@ -319,11 +290,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 2 can still login from IP 1.
-        response = self._login(
-            self.USER_2,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_1
-        )
+        response = self._login(self.USER_2, self.VALID_PASSWORD, ip_addr=self.IP_1)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     @override_settings(AXES_ONLY_USER_FAILURES=True)
@@ -332,20 +299,16 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 2 can still login from IP 2.
-        response = self._login(
-            self.USER_2,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_2
-        )
+        response = self._login(self.USER_2, self.VALID_PASSWORD, ip_addr=self.IP_2)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     @override_settings(AXES_ONLY_USER_FAILURES=True)
     def test_lockout_by_user_with_empty_username_allows_other_users_without_cache(self):
         # User with empty username is locked out from IP 1.
-        self._lockout_user_from_ip(username='', ip_addr=self.IP_1)
+        self._lockout_user_from_ip(username="", ip_addr=self.IP_1)
 
         # Still possible to access the login page
-        response = self.client.get(reverse('admin:login'), REMOTE_ADDR=self.IP_1)
+        response = self.client.get(reverse("admin:login"), REMOTE_ADDR=self.IP_1)
         self.assertContains(response, self.LOGIN_FORM_KEY, status_code=200, html=True)
 
     # Test for true and false positives when blocking by user and IP together.
@@ -356,11 +319,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 1 is still blocked from IP 1.
-        response = self._login(
-            self.USER_1,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_1
-        )
+        response = self._login(self.USER_1, self.VALID_PASSWORD, ip_addr=self.IP_1)
         self.assertEqual(response.status_code, self.BLOCKED)
 
     @override_settings(AXES_LOCK_OUT_BY_COMBINATION_USER_AND_IP=True)
@@ -369,11 +328,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 1 can still login from IP 2.
-        response = self._login(
-            self.USER_1,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_2
-        )
+        response = self._login(self.USER_1, self.VALID_PASSWORD, ip_addr=self.IP_2)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     @override_settings(AXES_LOCK_OUT_BY_COMBINATION_USER_AND_IP=True)
@@ -382,11 +337,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 2 can still login from IP 1.
-        response = self._login(
-            self.USER_2,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_1
-        )
+        response = self._login(self.USER_2, self.VALID_PASSWORD, ip_addr=self.IP_1)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     @override_settings(AXES_LOCK_OUT_BY_COMBINATION_USER_AND_IP=True)
@@ -395,20 +346,18 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 2 can still login from IP 2.
-        response = self._login(
-            self.USER_2,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_2
-        )
+        response = self._login(self.USER_2, self.VALID_PASSWORD, ip_addr=self.IP_2)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     @override_settings(AXES_LOCK_OUT_BY_COMBINATION_USER_AND_IP=True)
-    def test_lockout_by_user_and_ip_with_empty_username_allows_other_users_without_cache(self):
+    def test_lockout_by_user_and_ip_with_empty_username_allows_other_users_without_cache(
+        self,
+    ):
         # User with empty username is locked out from IP 1.
-        self._lockout_user_from_ip(username='', ip_addr=self.IP_1)
+        self._lockout_user_from_ip(username="", ip_addr=self.IP_1)
 
         # Still possible to access the login page
-        response = self.client.get(reverse('admin:login'), REMOTE_ADDR=self.IP_1)
+        response = self.client.get(reverse("admin:login"), REMOTE_ADDR=self.IP_1)
         self.assertContains(response, self.LOGIN_FORM_KEY, status_code=200, html=True)
 
     # Test for true and false positives when blocking by IP *OR* user (default)
@@ -418,11 +367,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 1 is still blocked from IP 1.
-        response = self._login(
-            self.USER_1,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_1
-        )
+        response = self._login(self.USER_1, self.VALID_PASSWORD, ip_addr=self.IP_1)
         self.assertEqual(response.status_code, self.BLOCKED)
 
     def test_lockout_by_ip_allows_when_same_user_diff_ip_using_cache(self):
@@ -430,11 +375,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 1 can still login from IP 2.
-        response = self._login(
-            self.USER_1,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_2
-        )
+        response = self._login(self.USER_1, self.VALID_PASSWORD, ip_addr=self.IP_2)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     def test_lockout_by_ip_blocks_when_diff_user_same_ip_using_cache(self):
@@ -442,11 +383,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 2 is also locked out from IP 1.
-        response = self._login(
-            self.USER_2,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_1
-        )
+        response = self._login(self.USER_2, self.VALID_PASSWORD, ip_addr=self.IP_1)
         self.assertEqual(response.status_code, self.BLOCKED)
 
     def test_lockout_by_ip_allows_when_diff_user_diff_ip_using_cache(self):
@@ -454,20 +391,16 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 2 can still login from IP 2.
-        response = self._login(
-            self.USER_2,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_2
-        )
+        response = self._login(self.USER_2, self.VALID_PASSWORD, ip_addr=self.IP_2)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     @override_settings(AXES_ONLY_USER_FAILURES=True)
     def test_lockout_by_user_with_empty_username_allows_other_users_using_cache(self):
         # User with empty username is locked out from IP 1.
-        self._lockout_user_from_ip(username='', ip_addr=self.IP_1)
+        self._lockout_user_from_ip(username="", ip_addr=self.IP_1)
 
         # Still possible to access the login page
-        response = self.client.get(reverse('admin:login'), REMOTE_ADDR=self.IP_1)
+        response = self.client.get(reverse("admin:login"), REMOTE_ADDR=self.IP_1)
         self.assertContains(response, self.LOGIN_FORM_KEY, status_code=200, html=True)
 
     # Test for true and false positives when blocking by user only.
@@ -478,11 +411,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 1 is still blocked from IP 1.
-        response = self._login(
-            self.USER_1,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_1
-        )
+        response = self._login(self.USER_1, self.VALID_PASSWORD, ip_addr=self.IP_1)
         self.assertEqual(response.status_code, self.BLOCKED)
 
     @override_settings(AXES_ONLY_USER_FAILURES=True)
@@ -491,11 +420,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 1 is also locked out from IP 2.
-        response = self._login(
-            self.USER_1,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_2
-        )
+        response = self._login(self.USER_1, self.VALID_PASSWORD, ip_addr=self.IP_2)
         self.assertEqual(response.status_code, self.BLOCKED)
 
     @override_settings(AXES_ONLY_USER_FAILURES=True)
@@ -504,11 +429,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 2 can still login from IP 1.
-        response = self._login(
-            self.USER_2,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_1
-        )
+        response = self._login(self.USER_2, self.VALID_PASSWORD, ip_addr=self.IP_1)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     @override_settings(AXES_ONLY_USER_FAILURES=True)
@@ -517,11 +438,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 2 can still login from IP 2.
-        response = self._login(
-            self.USER_2,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_2
-        )
+        response = self._login(self.USER_2, self.VALID_PASSWORD, ip_addr=self.IP_2)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     # Test for true and false positives when blocking by user and IP together.
@@ -532,11 +449,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 1 is still blocked from IP 1.
-        response = self._login(
-            self.USER_1,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_1
-        )
+        response = self._login(self.USER_1, self.VALID_PASSWORD, ip_addr=self.IP_1)
         self.assertEqual(response.status_code, self.BLOCKED)
 
     @override_settings(AXES_LOCK_OUT_BY_COMBINATION_USER_AND_IP=True)
@@ -545,11 +458,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 1 can still login from IP 2.
-        response = self._login(
-            self.USER_1,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_2
-        )
+        response = self._login(self.USER_1, self.VALID_PASSWORD, ip_addr=self.IP_2)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     @override_settings(AXES_LOCK_OUT_BY_COMBINATION_USER_AND_IP=True)
@@ -558,11 +467,7 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 2 can still login from IP 1.
-        response = self._login(
-            self.USER_2,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_1
-        )
+        response = self._login(self.USER_2, self.VALID_PASSWORD, ip_addr=self.IP_1)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     @override_settings(AXES_LOCK_OUT_BY_COMBINATION_USER_AND_IP=True)
@@ -571,18 +476,16 @@ class LoginTestCase(AxesTestCase):
         self._lockout_user1_from_ip1()
 
         # User 2 can still login from IP 2.
-        response = self._login(
-            self.USER_2,
-            self.VALID_PASSWORD,
-            ip_addr=self.IP_2
-        )
+        response = self._login(self.USER_2, self.VALID_PASSWORD, ip_addr=self.IP_2)
         self.assertEqual(response.status_code, self.ALLOWED)
 
     @override_settings(AXES_LOCK_OUT_BY_COMBINATION_USER_AND_IP=True)
-    def test_lockout_by_user_and_ip_with_empty_username_allows_other_users_using_cache(self):
+    def test_lockout_by_user_and_ip_with_empty_username_allows_other_users_using_cache(
+        self,
+    ):
         # User with empty username is locked out from IP 1.
-        self._lockout_user_from_ip(username='', ip_addr=self.IP_1)
+        self._lockout_user_from_ip(username="", ip_addr=self.IP_1)
 
         # Still possible to access the login page
-        response = self.client.get(reverse('admin:login'), REMOTE_ADDR=self.IP_1)
+        response = self.client.get(reverse("admin:login"), REMOTE_ADDR=self.IP_1)
         self.assertContains(response, self.LOGIN_FORM_KEY, status_code=200, html=True)
