@@ -13,23 +13,22 @@ class ModelsTestCase(AxesTestCase):
         self.failures_since_start = 42
 
         self.access_attempt = AccessAttempt(
-            failures_since_start=self.failures_since_start,
+            failures_since_start=self.failures_since_start
         )
         self.access_log = AccessLog()
 
     def test_access_attempt_str(self):
-        self.assertIn('Access', str(self.access_attempt))
+        self.assertIn("Access", str(self.access_attempt))
 
     def test_access_log_str(self):
-        self.assertIn('Access', str(self.access_log))
+        self.assertIn("Access", str(self.access_log))
 
 
 class MigrationsTestCase(AxesTestCase):
     def test_missing_migrations(self):
         executor = MigrationExecutor(connection)
         autodetector = MigrationAutodetector(
-            executor.loader.project_state(),
-            ProjectState.from_apps(apps),
+            executor.loader.project_state(), ProjectState.from_apps(apps)
         )
 
         changes = autodetector.changes(graph=executor.loader.graph)
